@@ -1,4 +1,5 @@
 import sys
+import getpass
 from cowait.tasks import TaskDefinition, TASK_LOG
 from cowait.engine import ProviderError, TaskCreationError
 from ..config import Config
@@ -11,23 +12,40 @@ from .push import push as run_push
 
 def test(
     config: Config,
-    push: bool,
     cluster_name: str = None,
+    mount: bool = True,
 ):
     logger = TestLogger()
     try:
         context = Context.open(config)
         cluster = context.get_cluster(cluster_name)
 
-        if push:
-            run_push()
-        else:
-            run_build(config)
+        volumes = {}
+        if mount and cluster.type == 'docker':
+            # when testing in docker, mount the local directory
+            # this avoids the problem of having to constantly rebuild in order to test
+            print('** Mounting', context.root_path)
+            volumes['/var/task'] = {
+                'bind': {
+                    'src': context.root_path,
+                    'mode': 'rw',
+                    'inherit': 'same-image',
+                },
+            }
 
         # execute the test task within the current image
         task = cluster.spawn(TaskDefinition(
             name='cowait.test',
             image=context.image,
+            owner=getpass.getuser(),
+            env={
+                **context.environment,
+                **context.dotenv,
+            },
+            volumes={
+                **context.get('volumes', {}),
+                **volumes,
+            },
         ))
 
         def destroy(*args):
