@@ -1,3 +1,4 @@
+from typing import List
 from kubernetes import client
 from .router import Router
 from ..const import LABEL_TASK_ID
@@ -16,17 +17,32 @@ class Traefik2Router(Router):
         cluster.on('prepare', self.on_prepare)
         cluster.on('spawn', self.on_spawn)
         cluster.on('kill', self.on_kill)
-
         self.config = cluster.args.get('traefik2', {})
-        self.secure = self.config.get('secure', False)
-        self.middlewares = self.config.get('middlewares', [])
-        self.entrypoints = self.config.get('entrypoints', ['web'])
 
-    def on_prepare(self, taskdef):
+    @property
+    def secure(self) -> bool:
+        return self.cert_resolver is not None
+
+    @property
+    def middlewares(self) -> List[str]:
+        return self.config.get('middlewares', [])
+
+    @property
+    def entrypoints(self) -> List[str]:
+        return self.config.get('entrypoints', ['web', 'websecure'])
+
+    @property
+    def cert_resolver(self) -> str:
+        return self.config.get('certresolver', None)
+
+    @property
+    def domain(self) -> str:
         domain = self.cluster.domain
         if domain is None:
             raise RuntimeError('No cluster domain configured')
+        return domain
 
+    def on_prepare(self, taskdef):
         protocol = 'https' if self.secure else 'http'
 
         for path, port in taskdef.routes.items():
@@ -34,9 +50,9 @@ class Traefik2Router(Router):
                 raise RuntimeError(f'Paths must start with /, got {path}')
 
             taskdef.routes[path] = {
-                'port': port,
+                'port': int(port),
                 'path': path,
-                'url': f'{protocol}://{taskdef.id}.{domain}{path}',
+                'url': f'{protocol}://{taskdef.id}.{self.domain}{path}',
             }
 
         return taskdef
@@ -51,18 +67,18 @@ class Traefik2Router(Router):
             idx += 1
 
             ports.append(client.V1ServicePort(
-                port=port,
-                target_port=port,
+                port=int(port),
+                target_port=int(port),
             ))
 
             host = f'{task.id}.{self.cluster.domain}'
             routes.append({
+                'kind': 'Rule',
                 'match': f'Host(`{host}`) && PathPrefix(`{path}`)',
                 'middlewares': self.middlewares,
-                'kind': 'Rule',
                 'services': [
-                    {'name': task.id, 'port': port}
-                ]
+                    {'name': task.id, 'port': int(port)}
+                ],
             })
 
         if len(routes) == 0:
@@ -89,6 +105,15 @@ class Traefik2Router(Router):
             ),
         )
 
+        ingress = {
+            'entryPoints': self.entrypoints,
+            'routes': routes,
+        }
+        if self.secure:
+            ingress['tls'] = {
+                'certResolver': self.cert_resolver,
+            }
+
         self.cluster.custom.create_namespaced_custom_object(
             group=TRAEFIK2_API_GROUP,
             version=TRAEFIK2_API_VERSION,
@@ -105,10 +130,7 @@ class Traefik2Router(Router):
                         'ingress-for': task.id
                     },
                 },
-                'spec': {
-                    'entryPoints': self.entrypoints,
-                    'routes': routes,
-                }
+                'spec': ingress,
             },
         )
 
@@ -118,15 +140,16 @@ class Traefik2Router(Router):
                 namespace=self.cluster.namespace,
                 name=task_id,
             )
-        except client.rest.ApiException:
-            pass
+        except client.rest.ApiException as e:
+            print('!! error deleting Kubernetes Service:', e)
 
         try:
-            self.cluster.custom.delete_cluster_custom_object(
+            self.cluster.custom.delete_namespaced_custom_object(
                 group=TRAEFIK2_API_GROUP,
                 version=TRAEFIK2_API_VERSION,
                 plural=TRAEFIK2_INGRESSROUTE_PLURAL,
+                namespace=self.cluster.namespace,
                 name=task_id,
             )
-        except client.rest.ApiException:
-            pass
+        except client.rest.ApiException as e:
+            print('!! error deleting IngressRoute:', e)
